@@ -1,8 +1,7 @@
-
 .attach.cast <- function(x, cast, udt, array = TRUE)
 {
     x <- .db.data.frame2db.Rquery(x)
- 
+
     for (i in seq_len(length(names(x)))) {
         if (array && x@.col.data_type[i] == "array") {
             z <- x[names(x)[i]][,]
@@ -127,7 +126,7 @@ as.interval <- function(x, ...)
 db.date.style <- function (conn.id = 1, set = NULL)
 {
     if (is.null(set)) {
-        res <- .get.res(sql = "show datestyle", conn.id = conn.id)
+        res <- db.q("show datestyle", conn.id = conn.id, verbose = FALSE)
         return (res)
     } else {
         res <- try(.db.getQuery(paste("set datestyle to", set),
